// SPDX-License-Identifier: GPL-2.0-only OR MIT
/*

Copyright (C) 2023 The Falco Authors.

This file is dual licensed under either the MIT or GPL 2. See MIT.txt
or GPL2.txt for full copies of the license.

*/
#pragma once

/* taken from driver/API_VERSION */
#define PPM_API_CURRENT_VERSION_MAJOR 10
#define PPM_API_CURRENT_VERSION_MINOR 1
#define PPM_API_CURRENT_VERSION_PATCH 0

/* taken from driver/SCHEMA_VERSION */
#define PPM_SCHEMA_CURRENT_VERSION_MAJOR 4
#define PPM_SCHEMA_CURRENT_VERSION_MINOR 5
#define PPM_SCHEMA_CURRENT_VERSION_PATCH 1

#include "ppm_api_version.h"

#define DRIVER_VERSION "10.2.0+driver"

#define DRIVER_NAME "falco"

#define DRIVER_DEVICE_NAME "falco"

#define DRIVER_COMMIT "a078853fe47db0199ed2c5ca58cb548754017aa1"

#ifndef KBUILD_MODNAME
#define KBUILD_MODNAME DRIVER_NAME
#endif
